@@ -6,7 +6,7 @@
     <message>
         <location filename="../qml/ControlCenter.qml" line="188"/>
         <source>Wi-Fi</source>
-        <translation>واي-فاي</translation>
+        <translation>الشبكة اللاسلكية</translation>
     </message>
     <message>
         <location filename="../qml/ControlCenter.qml" line="191"/>
