@@ -1,33 +1,42 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
 <TS version="2.1" language="zh_CN">
+<context>
+    <name>Activity</name>
+    <message>
+        <location filename="../src/activity.cpp" line="166"/>
+        <source>Desktop</source>
+        <translation>桌面</translation>
+    </message>
+</context>
 <context>
     <name>ControlCenter</name>
     <message>
-        <location filename="../qml/ControlCenter.qml" line="188"/>
+        <location filename="../qml/ControlCenter.qml" line="217"/>
         <source>Wi-Fi</source>
         <translation>无线网络</translation>
     </message>
     <message>
-        <location filename="../qml/ControlCenter.qml" line="191"/>
-        <location filename="../qml/ControlCenter.qml" line="214"/>
+        <location filename="../qml/ControlCenter.qml" line="220"/>
+        <location filename="../qml/ControlCenter.qml" line="236"/>
+        <location filename="../qml/ControlCenter.qml" line="253"/>
         <source>On</source>
         <translation>打开</translation>
     </message>
     <message>
-        <location filename="../qml/ControlCenter.qml" line="191"/>
-        <location filename="../qml/ControlCenter.qml" line="203"/>
-        <location filename="../qml/ControlCenter.qml" line="214"/>
+        <location filename="../qml/ControlCenter.qml" line="220"/>
+        <location filename="../qml/ControlCenter.qml" line="236"/>
+        <location filename="../qml/ControlCenter.qml" line="253"/>
         <source>Off</source>
         <translation>关闭</translation>
     </message>
     <message>
-        <location filename="../qml/ControlCenter.qml" line="202"/>
+        <location filename="../qml/ControlCenter.qml" line="235"/>
         <source>Bluetooth</source>
         <translation>蓝牙</translation>
     </message>
     <message>
-        <location filename="../qml/ControlCenter.qml" line="213"/>
+        <location filename="../qml/ControlCenter.qml" line="252"/>
         <source>Dark Mode</source>
         <translation>深色模式</translation>
     </message>
@@ -35,7 +44,7 @@
 <context>
     <name>main</name>
     <message>
-        <location filename="../qml/main.qml" line="71"/>
+        <location filename="../qml/main.qml" line="75"/>
         <source>Close</source>
         <translation>关闭</translation>
     </message>
